# Regex Field Validator

A Drupal 10/11 custom module that adds regular expression validation to text fields with backend configuration options.

## Features

- Adds regex validation to plain text and long text fields
- Backend configuration for regex patterns and error messages
- Support for both textfield and textarea widgets
- Compatible with Drupal 10 and 11
- Easy to enable/disable per field instance

## Installation

1. Copy the `regex_field_validator` folder to your `/modules/custom/` directory
2. Enable the module via Drush: `drush en regex_field_validator`
3. Or enable via the admin interface: `/admin/modules`

## Usage

### For Text Fields (Single Line)

1. Go to your content type's "Manage form display" page
2. Find your text field and change the widget to "Text field with regex validation"
3. Click the settings gear icon
4. Check "Enable regex validation"
5. Enter your regex pattern (without delimiters)
6. Optionally customize the error message
7. Save the configuration

### For Long Text Fields (Multi-line)

1. Go to your content type's "Manage form display" page
2. Find your long text field and change the widget to "Textarea with regex validation"
3. Follow the same configuration steps as above

## Example Regex Patterns

- **Alphanumeric only**: `^[A-Za-z0-9]+$`
- **Email format**: `^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$`
- **Phone number (US format)**: `^\(\d{3}\) \d{3}-\d{4}$`
- **URL format**: `^https?:\/\/.+$`
- **Letters and spaces only**: `^[A-Za-z\s]+$`
- **Numbers only**: `^\d+$`

## Configuration Options

- **Enable regex validation**: Checkbox to enable/disable validation
- **Regular Expression Pattern**: The regex pattern to validate against
- **Validation Error Message**: Custom error message displayed when validation fails

## Technical Details

- The module extends Drupal's core text field widgets
- Validation occurs on the server side during form submission
- Patterns are automatically wrapped with delimiters if not provided
- Compatible with field API and standard Drupal form validation

## Requirements

- Drupal 10 or 11
- PHP PCRE support (standard in most PHP installations)
- Field module (core)
- Text module (core)

## Maintainers

- Rahul Yadav - 5418ryadav

## Support

This module is provided as-is for educational and development purposes. Test thoroughly before using in production environments.